/**
 * Copyright (c) 2019-2020 mol* contributors, licensed under MIT, See LICENSE file for more info.
 *
 * @author Alexander Rose <alexander.rose@weirdbyte.de>
 */
import { Renderable, RenderableState } from '../renderable';
import { WebGLContext } from '../webgl/context';
import { AttributeSpec, Values, ElementsSpec, ValueSpec, DefineSpec } from './schema';
export declare const SpheresSchema: {
    aGroup: AttributeSpec<"float32">;
    aPosition: AttributeSpec<"float32">;
    aMapping: AttributeSpec<"float32">;
    elements: ElementsSpec<"uint32">;
    padding: ValueSpec<"number">;
    dDoubleSided: DefineSpec<"boolean">;
    dIgnoreLight: DefineSpec<"boolean">;
    dXrayShaded: DefineSpec<"boolean">;
    uSize: import("./schema").UniformSpec<"f">;
    uSizeTexDim: import("./schema").UniformSpec<"v2">;
    tSize: import("./schema").TextureSpec<"image-uint8">;
    dSizeType: DefineSpec<"string">;
    uSizeFactor: import("./schema").UniformSpec<"f">;
    dLightCount: DefineSpec<"number">;
    aInstance: AttributeSpec<"float32">;
    aTransform: AttributeSpec<"float32">;
    uAlpha: import("./schema").UniformSpec<"f">;
    uMetalness: import("./schema").UniformSpec<"f">;
    uRoughness: import("./schema").UniformSpec<"f">;
    uVertexCount: import("./schema").UniformSpec<"i">;
    uInstanceCount: import("./schema").UniformSpec<"i">;
    uGroupCount: import("./schema").UniformSpec<"i">;
    uInvariantBoundingSphere: import("./schema").UniformSpec<"v4">;
    drawCount: ValueSpec<"number">;
    instanceCount: ValueSpec<"number">;
    alpha: ValueSpec<"number">;
    matrix: ValueSpec<"m4">;
    transform: ValueSpec<"float32">;
    extraTransform: ValueSpec<"float32">;
    hasReflection: ValueSpec<"boolean">;
    boundingSphere: ValueSpec<"sphere">;
    invariantBoundingSphere: ValueSpec<"sphere">;
    dClipObjectCount: DefineSpec<"number">;
    dClipVariant: DefineSpec<"string">;
    uClippingTexDim: import("./schema").UniformSpec<"v2">;
    tClipping: import("./schema").TextureSpec<"image-uint8">;
    dClipping: DefineSpec<"boolean">;
    uSubstanceTexDim: import("./schema").UniformSpec<"v2">;
    tSubstance: import("./schema").TextureSpec<"image-uint8">;
    dSubstance: DefineSpec<"boolean">;
    uSubstanceGridDim: import("./schema").UniformSpec<"v3">;
    uSubstanceGridTransform: import("./schema").UniformSpec<"v4">;
    tSubstanceGrid: import("./schema").TextureSpec<"texture">;
    dSubstanceType: DefineSpec<"string">;
    uTransparencyTexDim: import("./schema").UniformSpec<"v2">;
    tTransparency: import("./schema").TextureSpec<"image-uint8">;
    dTransparency: DefineSpec<"boolean">;
    transparencyAverage: ValueSpec<"number">;
    uTransparencyGridDim: import("./schema").UniformSpec<"v3">;
    uTransparencyGridTransform: import("./schema").UniformSpec<"v4">;
    tTransparencyGrid: import("./schema").TextureSpec<"texture">;
    dTransparencyType: DefineSpec<"string">;
    uOverpaintTexDim: import("./schema").UniformSpec<"v2">;
    tOverpaint: import("./schema").TextureSpec<"image-uint8">;
    dOverpaint: DefineSpec<"boolean">;
    uOverpaintGridDim: import("./schema").UniformSpec<"v3">;
    uOverpaintGridTransform: import("./schema").UniformSpec<"v4">;
    tOverpaintGrid: import("./schema").TextureSpec<"texture">;
    dOverpaintType: DefineSpec<"string">;
    uMarker: import("./schema").UniformSpec<"f">;
    uMarkerTexDim: import("./schema").UniformSpec<"v2">;
    tMarker: import("./schema").TextureSpec<"image-uint8">;
    dMarkerType: DefineSpec<"string">;
    markerAverage: ValueSpec<"number">;
    markerStatus: ValueSpec<"number">;
    uColor: import("./schema").UniformSpec<"v3">;
    uColorTexDim: import("./schema").UniformSpec<"v2">;
    uColorGridDim: import("./schema").UniformSpec<"v3">;
    uColorGridTransform: import("./schema").UniformSpec<"v4">;
    tColor: import("./schema").TextureSpec<"image-uint8">;
    tPalette: import("./schema").TextureSpec<"image-uint8">;
    tColorGrid: import("./schema").TextureSpec<"texture">;
    dColorType: DefineSpec<"string">;
    dUsePalette: DefineSpec<"boolean">;
};
export declare type SpheresSchema = typeof SpheresSchema;
export declare type SpheresValues = Values<SpheresSchema>;
export declare function SpheresRenderable(ctx: WebGLContext, id: number, values: SpheresValues, state: RenderableState, materialId: number): Renderable<SpheresValues>;
